[![astropy](http://img.shields.io/badge/powered%20by-AstroPy-orange.svg?style=flat)](http://www.astropy.org/)

Specvizitor is a Python GUI application for a visual inspection of astronomical spectroscopic data. The main goal is to provide a flexible tool for inspecting **large** and **homogeneous** spectroscopic samples of galaxies. This includes but not limited to [wide-field slitless spectroscopic (WFSS)](https://jwst-docs.stsci.edu/methods-and-roadmaps/jwst-wide-field-slitless-spectroscopy) data from the James Webb Space Telescope (JWST). Originally developed for the JWST Cycle 1 program "[FRESCO](https://jwst-fresco.astro.unige.ch)", this software can be easily adapted for a variety of spectroscopic data sets represented in standard data formats used in the astronomy community (FITS, ASCII, etc.).

For installation instructions, see the [online documentation](https://ivkram.github.io/specvizitor/).

![Specvizitor GUI](https://github.com/ivkram/specvizitor/blob/main/docs/screenshots/specvizitor_gui_showcase.gif)

## Citation

Click [here](https://ivkram.github.io/specvizitor/citation) to read about how you can acknowledge the use of specvizitor.

## License

Specvizitor is licensed under the 3-clause BSD license - see the [LICENSE.txt](https://github.com/ivkram/specvizitor/blob/main/LICENSE.txt) file.
